==> spectacle-6.5.5-1.gpkg.tar: image/usr/src/debug/kde-plasma/spectacle-6.5.5/spectacle-6.5.5_build/src/.qt/rcc/qrc_qmake_org_kde_spectacle_private.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x89,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x76,0x8,0xfd,0x13,0x0,0x86,0x58,0x47,0x1e,0x20,0x75,0x73,
  0xff,0x37,0xb9,0xd4,0x2d,0xe2,0x78,0xb3,0x9c,0x90,0xa,0x40,0xbc,0x8d,0x5f,0xc6,
  0x41,0x3a,0xa1,0x5d,0xe0,0x2,0x2,0x58,0x21,0x82,0x7,0x3f,0x0,0x3e,0x0,0x3e,
  0x0,0x86,0x86,0x67,0xcc,0x20,0x51,0x14,0xf5,0xd6,0xa1,0x2a,0x5e,0x8a,0x6a,0xf,
  0x55,0x98,0xf8,0x9b,0x33,0x94,0x3a,0xcc,0x5d,0x94,0xf3,0x22,0x9a,0x32,0xc5,0xa6,
  0x87,0x6f,0x52,0x7c,0x96,0x67,0xda,0x8d,0xba,0x43,0x51,0x4b,0xef,0xfc,0x38,0x86,
  0x80,0x3f,0x96,0xcd,0xe,0x23,0xe0,0xad,0x3,0xa8,0x78,0xa7,0xbf,0xab,0xad,0x15,
  0xd,0xb3,0x39,0x66,0xe8,0x76,0x5f,0x87,0xe,0xfd,0xf2,0x77,0xcb,0xd5,0xbd,0xbe,
  0x24,0xfc,0xcf,0x36,0xe0,0x32,0x82,0x8a,0xbc,0xed,0x9a,0x22,0xb6,0xbe,0x75,0x11,
  0x9c,0x87,0xb7,0x7b,0x89,0x50,0x92,0xbd,0xca,0x6f,0xb9,0x8f,0xf6,0x4e,0xcb,0xa9,
  0x41,0xa2,0xdc,0xc5,0x98,0x2,0x80,0x1,0x41,0x30,0xe9,0xba,0x66,0x1,0xea,0x80,
  0xef,0x7f,0x4d,0xb3,0xe9,0xb5,0x5c,0x75,0x58,0x1e,0x72,0xdf,0xe2,0xd2,0x43,0x9a,
  0x17,0x86,0x44,0xd,0xad,0x2a,0x27,0xd5,0xbe,0x74,0xa1,0x3d,0xa8,0x83,0x16,0x51,
  0xbe,0xb7,0x73,0x62,0x26,0x92,0xed,0xe3,0x55,0x5a,0xe,0x11,0xdc,0x4a,0x5d,0xf7,
  0x2d,0xa2,0x7c,0x6a,0x5d,0x6f,0x11,0xf1,0x6d,0x21,0xe7,0x2b,0x12,0x1f,0x5e,0xcb,
  0x8c,0x6d,0xaf,0x6c,0x53,0xcc,0x35,0xf4,0xae,0xc9,0xc7,0x47,0x2e,0xf6,0xc5,0x9a,
  0x97,0x13,0x3f,0x9,0xba,0xcb,0x34,0x5e,0xf6,0x4a,0x7c,0xae,0x31,0xcf,0xa2,0xfc,
  0x55,0xea,0xe2,0x72,0xa2,0xfe,0xcc,0x2c,0xa0,0x47,0xf8,0x6e,0xe3,0xb4,0x4a,0x48,
  0x47,0xf7,0x78,0x95,0x31,0x1e,0x72,0x75,0x2f,0x80,0xaa,0xa8,0xa1,0xca,0x8,0xc9,
  0xc8,0x48,0x92,0x82,0x64,0x59,0x3,0x20,0x46,0x40,0x9c,0x45,0xdb,0x36,0x42,0x48,
  0x38,0x9a,0x82,0x18,0x90,0xea,0x30,0xa8,0x98,0x72,0x22,0x92,0xd3,0x34,0xd3,0x66,
  0x1c,0x9,0xc7,0x8f,0x3f,0x8c,0x39,0x42,0xf2,0x76,0x5b,0xef,0x1a,0xd8,0x58,0xe,
  0xd5,0x17,0x4e,0xc2,0x82,0xe6,0xd8,0xa6,0x76,0x4,0xba,0x66,0xcb,0x40,0x96,0xca,
  0x95,0x59,0x67,0x9f,0xb0,0xcc,0x9d,0x31,0xd7,0x79,0xe,0xc1,0xbb,0xe4,0xf8,0x80,
  0x1c,0x22,0x19,0xf4,0xa0,0x31,0xc0,0x5,0xf9,0xf5,0x50,0x2d,0x47,0x7,0x21,0x2d,
  0x8f,0x13,0x15,0x9e,0xf,0x82,0xdf,0xad,0xeb,0x86,0x2a,0xb3,0xa1,0x6e,0x34,0xfb,
  0xe6,0x88,0xb,0xda,0x13,0x5,0xe0,0x62,0xc2,0x1b,0xfa,0xd0,0xb,0x81,0x63,0x80,
  0x3d,0xb4,0x5e,0x91,0xaa,0xd1,0xc6,0xa0,0x23,0x69,0x6c,0x7c,0xcb,0x97,0xc9,0xa3,
  0xd0,0xba,0xc2,0xb5,0xf7,0x5a,0x88,0x78,0xfd,0xa3,0xc,0x78,0xb8,0xc0,0xc0,0x23,
  0x9f,0xd1,0x52,0xe5,0xe4,0xd7,0x48,0xcd,0x7d,0xfb,0x4a,0xe4,0x25,0x58,0x2b,0xf8,
  0xa2,0x3d,0x46,0x2,0x46,0x92,0xc1,0xe4,0xbd,0xd1,0x2b,0x97,0x94,0x37,0x3,0x60,
  0xae,0x3b,0xbd,0xcc,0xcf,0x2f,0x7,0x18,0x88,0x78,0x7e,0xa,0xcf,0x4b,0x7c,0x5,
  0x72,0x6c,0x38,0xb0,0x14,0x42,0x5c,0x3f,0x1e,0x9c,0xce,0x52,0xbf,0xb2,0x2a,0x62,
  0xe6,0x5a,0xc0,0xea,0x90,0x36,0xf0,0x56,0x0,0xa4,0x3b,0x23,0x56,0x44,0xea,0x78,
  0x5a,0x1c,0xed,0x85,0x41,0x26,0xc6,0x44,0x6,0xc4,0xb3,0xf1,0xc,0xca,0xf9,0x6e,
  0x4c,0x67,0x60,0xcb,0x5f,0x87,0x77,0x53,0x6e,0x45,0x47,0x1d,0xdc,0xe2,0x88,0x57,
  0xdc,0x92,0x45,0x6f,0x6f,0xe9,0x1b,0x70,0x21,0x58,0x9a,0x1e,0x33,0x3d,0xa9,0x40,
  0x27,0x2e,0x45,0xb9,0x27,0xe3,0x16,0xb3,0x7d,0x3c,0xa2,0xbf,0x9e,0x76,0xe5,0x1f,
  0x4f,0xa,0x1a,0x37,0x4c,0x99,0x38,0x39,0x2b,0x16,0xb0,0xa7,0xe9,0xee,0x2b,0x1f,
  0x85,0x7,0x6e,0x95,0xf5,0xcb,0x92,0x9e,0xa8,0xa8,0xb2,0x63,0x93,0x90,0xdc,0xf0,
  0x13,0x9d,0x4a,0x30,0x29,0x1f,0xab,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // spectacle
  0x0,0x9,
  0xb,0xaa,0x8e,0xe5,
  0x0,0x73,
  0x0,0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x61,0x0,0x63,0x0,0x6c,0x0,0x65,
    // private
  0x0,0x7,
  0x7,0x90,0xc8,0x45,
  0x0,0x70,
  0x0,0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,0x74,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle/private
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle/private/qmldir
  0x0,0x0,0x0,0x5a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xc3,0x6c,0x9b,0xab,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> spectacle-6.5.5-2.gpkg.tar: image/usr/src/debug/kde-plasma/spectacle-6.5.5/spectacle-6.5.5_build/src/.qt/rcc/qrc_qmake_org_kde_spectacle_private.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0x89,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x76,0x8,0xfd,0x13,0x0,0x86,0x58,0x47,0x1e,0x20,0x75,0x73,
  0xff,0x37,0xb9,0xd4,0x2d,0xe2,0x78,0xb3,0x9c,0x90,0xa,0x40,0xbc,0x8d,0x5f,0xc6,
  0x41,0x3a,0xa1,0x5d,0xe0,0x2,0x2,0x58,0x21,0x82,0x7,0x3f,0x0,0x3e,0x0,0x3e,
  0x0,0x86,0x86,0x67,0xcc,0x20,0x51,0x14,0xf5,0xd6,0xa1,0x2a,0x5e,0x8a,0x6a,0xf,
  0x55,0x98,0xf8,0x9b,0x33,0x94,0x3a,0xcc,0x5d,0x94,0xf3,0x22,0x9a,0x32,0xc5,0xa6,
  0x87,0x6f,0x52,0x7c,0x96,0x67,0xda,0x8d,0xba,0x43,0x51,0x4b,0xef,0xfc,0x38,0x86,
  0x80,0x3f,0x96,0xcd,0xe,0x23,0xe0,0xad,0x3,0xa8,0x78,0xa7,0xbf,0xab,0xad,0x15,
  0xd,0xb3,0x39,0x66,0xe8,0x76,0x5f,0x87,0xe,0xfd,0xf2,0x77,0xcb,0xd5,0xbd,0xbe,
  0x24,0xfc,0xcf,0x36,0xe0,0x32,0x82,0x8a,0xbc,0xed,0x9a,0x22,0xb6,0xbe,0x75,0x11,
  0x9c,0x87,0xb7,0x7b,0x89,0x50,0x92,0xbd,0xca,0x6f,0xb9,0x8f,0xf6,0x4e,0xcb,0xa9,
  0x41,0xa2,0xdc,0xc5,0x98,0x2,0x80,0x1,0x41,0x30,0xe9,0xba,0x66,0x1,0xea,0x80,
  0xef,0x7f,0x4d,0xb3,0xe9,0xb5,0x5c,0x75,0x58,0x1e,0x72,0xdf,0xe2,0xd2,0x43,0x9a,
  0x17,0x86,0x44,0xd,0xad,0x2a,0x27,0xd5,0xbe,0x74,0xa1,0x3d,0xa8,0x83,0x16,0x51,
  0xbe,0xb7,0x73,0x62,0x26,0x92,0xed,0xe3,0x55,0x5a,0xe,0x11,0xdc,0x4a,0x5d,0xf7,
  0x2d,0xa2,0x7c,0x6a,0x5d,0x6f,0x11,0xf1,0x6d,0x21,0xe7,0x2b,0x12,0x1f,0x5e,0xcb,
  0x8c,0x6d,0xaf,0x6c,0x53,0xcc,0x35,0xf4,0xae,0xc9,0xc7,0x47,0x2e,0xf6,0xc5,0x9a,
  0x97,0x13,0x3f,0x9,0xba,0xcb,0x34,0x5e,0xf6,0x4a,0x7c,0xae,0x31,0xcf,0xa2,0xfc,
  0x55,0xea,0xe2,0x72,0xa2,0xfe,0xcc,0x2c,0xa0,0x47,0xf8,0x6e,0xe3,0xb4,0x4a,0x48,
  0x47,0xf7,0x78,0x95,0x31,0x1e,0x72,0x75,0x2f,0x80,0xaa,0xa8,0xa1,0xca,0x8,0xc9,
  0xc8,0x48,0x92,0x82,0x64,0x59,0x3,0x20,0x46,0x40,0x9c,0x45,0xdb,0x36,0x42,0x48,
  0x38,0x9a,0x82,0x18,0x90,0xea,0x30,0xa8,0x98,0x72,0x22,0x92,0xd3,0x34,0xd3,0x66,
  0x1c,0x9,0xc7,0x8f,0x3f,0x8c,0x39,0x42,0xf2,0x76,0x5b,0xef,0x1a,0xd8,0x58,0xe,
  0xd5,0x17,0x4e,0xc2,0x82,0xe6,0xd8,0xa6,0x76,0x4,0xba,0x66,0xcb,0x40,0x96,0xca,
  0x95,0x59,0x67,0x9f,0xb0,0xcc,0x9d,0x31,0xd7,0x79,0xe,0xc1,0xbb,0xe4,0xf8,0x80,
  0x1c,0x22,0x19,0xf4,0xa0,0x31,0xc0,0x5,0xf9,0xf5,0x50,0x2d,0x47,0x7,0x21,0x2d,
  0x8f,0x13,0x15,0x9e,0xf,0x82,0xdf,0xad,0xeb,0x86,0x2a,0xb3,0xa1,0x6e,0x34,0xfb,
  0xe6,0x88,0xb,0xda,0x13,0x5,0xe0,0x62,0xc2,0x1b,0xfa,0xd0,0xb,0x81,0x63,0x80,
  0x3d,0xb4,0x5e,0x91,0xaa,0xd1,0xc6,0xa0,0x23,0x69,0x6c,0x7c,0xcb,0x97,0xc9,0xa3,
  0xd0,0xba,0xc2,0xb5,0xf7,0x5a,0x88,0x78,0xfd,0xa3,0xc,0x78,0xb8,0xc0,0xc0,0x23,
  0x9f,0xd1,0x52,0xe5,0xe4,0xd7,0x48,0xcd,0x7d,0xfb,0x4a,0xe4,0x25,0x58,0x2b,0xf8,
  0xa2,0x3d,0x46,0x2,0x46,0x92,0xc1,0xe4,0xbd,0xd1,0x2b,0x97,0x94,0x37,0x3,0x60,
  0xae,0x3b,0xbd,0xcc,0xcf,0x2f,0x7,0x18,0x88,0x78,0x7e,0xa,0xcf,0x4b,0x7c,0x5,
  0x72,0x6c,0x38,0xb0,0x14,0x42,0x5c,0x3f,0x1e,0x9c,0xce,0x52,0xbf,0xb2,0x2a,0x62,
  0xe6,0x5a,0xc0,0xea,0x90,0x36,0xf0,0x56,0x0,0xa4,0x3b,0x23,0x56,0x44,0xea,0x78,
  0x5a,0x1c,0xed,0x85,0x41,0x26,0xc6,0x44,0x6,0xc4,0xb3,0xf1,0xc,0xca,0xf9,0x6e,
  0x4c,0x67,0x60,0xcb,0x5f,0x87,0x77,0x53,0x6e,0x45,0x47,0x1d,0xdc,0xe2,0x88,0x57,
  0xdc,0x92,0x45,0x6f,0x6f,0xe9,0x1b,0x70,0x21,0x58,0x9a,0x1e,0x33,0x3d,0xa9,0x40,
  0x27,0x2e,0x45,0xb9,0x27,0xe3,0x16,0xb3,0x7d,0x3c,0xa2,0xbf,0x9e,0x76,0xe5,0x1f,
  0x4f,0xa,0x1a,0x37,0x4c,0x99,0x38,0x39,0x2b,0x16,0xb0,0xa7,0xe9,0xee,0x2b,0x1f,
  0x85,0x7,0x6e,0x95,0xf5,0xcb,0x92,0x9e,0xa8,0xa8,0xb2,0x63,0x93,0x90,0xdc,0xf0,
  0x13,0x9d,0x4a,0x30,0x29,0x1f,0xab,0x2a,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // spectacle
  0x0,0x9,
  0xb,0xaa,0x8e,0xe5,
  0x0,0x73,
  0x0,0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x61,0x0,0x63,0x0,0x6c,0x0,0x65,
    // private
  0x0,0x7,
  0x7,0x90,0xc8,0x45,
  0x0,0x70,
  0x0,0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,0x74,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle/private
  0x0,0x0,0x0,0x46,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt/qml/org/kde/spectacle/private/qmldir
  0x0,0x0,0x0,0x5a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0xb,0x90,0x34,0xb1,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_spectacle_private)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_spectacle_private)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
